# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: user.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nuser.proto\x12\x04user\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0c\x63ommon.proto\"\xcf\x01\n\x04User\x12\x0b\n\x03_id\x18\x01 \x01(\x05\x12\x12\n\nfirst_name\x18\x02 \x01(\t\x12\x11\n\tlast_name\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x1c\n\x04type\x18\x05 \x01(\x0b\x32\x0e.user.UserType\x12.\n\x0fprofile_picture\x18\x06 \x01(\x0b\x32\x10.common.DocumentH\x00\x88\x01\x01\x12\x15\n\x08verified\x18\x07 \x01(\x08H\x01\x88\x01\x01\x42\x12\n\x10_profile_pictureB\x0b\n\t_verified\"&\n\x08UserType\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\r\n\x05label\x18\x02 \x01(\t2A\n\x0eUserController\x12/\n\x07GetUser\x12\x16.google.protobuf.Empty\x1a\n.user.User\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'user_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_USER']._serialized_start=64
  _globals['_USER']._serialized_end=271
  _globals['_USERTYPE']._serialized_start=273
  _globals['_USERTYPE']._serialized_end=311
  _globals['_USERCONTROLLER']._serialized_start=313
  _globals['_USERCONTROLLER']._serialized_end=378
# @@protoc_insertion_point(module_scope)
