# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: authentication.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import user_pb2 as user__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x14\x61uthentication.proto\x12\x0e\x61uthentication\x1a\x1bgoogle/protobuf/empty.proto\x1a\nuser.proto\"/\n\x0cLoginRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"W\n\rSignupRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x12\n\nfirst_name\x18\x03 \x01(\t\x12\x11\n\tlast_name\x18\x04 \x01(\t\"8\n\x0bJWTResponse\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x1c\n\x04type\x18\x02 \x01(\x0b\x32\x0e.user.UserType2\xdd\x01\n\x18\x41uthenticationController\x12\x44\n\x05Login\x12\x1c.authentication.LoginRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12\x46\n\x06Signup\x12\x1d.authentication.SignupRequest\x1a\x1b.authentication.JWTResponse\"\x00\x12\x33\n\x0bGetUserData\x12\x16.google.protobuf.Empty\x1a\n.user.User\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'authentication_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_LOGINREQUEST']._serialized_start=81
  _globals['_LOGINREQUEST']._serialized_end=128
  _globals['_SIGNUPREQUEST']._serialized_start=130
  _globals['_SIGNUPREQUEST']._serialized_end=217
  _globals['_JWTRESPONSE']._serialized_start=219
  _globals['_JWTRESPONSE']._serialized_end=275
  _globals['_AUTHENTICATIONCONTROLLER']._serialized_start=278
  _globals['_AUTHENTICATIONCONTROLLER']._serialized_end=499
# @@protoc_insertion_point(module_scope)
