# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: analyzer.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
import common_pb2 as common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x61nalyzer.proto\x12\x08\x61nalyzer\x1a\x1bgoogle/protobuf/empty.proto\x1a\x0c\x63ommon.proto\"$\n\x04Post\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x61pproved\x18\x02 \x01(\x08\"&\n\x05Posts\x12\x1d\n\x05posts\x18\x01 \x03(\x0b\x32\x0e.analyzer.Post2z\n\x12\x41nalyzerController\x12\x32\n\x08GetPosts\x12\x13.common.GetItemByID\x1a\x0f.analyzer.Posts\"\x00\x12\x30\n\x07GetPost\x12\x13.common.GetItemByID\x1a\x0e.analyzer.Post\"\x00\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'analyzer_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _globals['_POST']._serialized_start=71
  _globals['_POST']._serialized_end=107
  _globals['_POSTS']._serialized_start=109
  _globals['_POSTS']._serialized_end=147
  _globals['_ANALYZERCONTROLLER']._serialized_start=149
  _globals['_ANALYZERCONTROLLER']._serialized_end=271
# @@protoc_insertion_point(module_scope)
